Copyright © 2014-2017 Arjan Scherpenisse
Authors: Arjan Scherpenisse (arjan@miraclethings.nl).
| all/0 | Compile all files. |
| all_sync/0 | |
| all_task/1 | |
| code_path_check/1 | Check if the application is present in the current code path. |
| compile_options/1 | |
| ld/0 | Load all changed beam files, return list of reloaded modules. |
| ld/1 | Load a specific beam file, reattach any observers etc. |
| recompile/1 | |
| recompile_task/1 | |
| run_cmd/1 | |
| run_cmd/3 | |
| run_cmd_task/3 | |
| run_cmd_task_buffalo/3 | |
| start/0 | Compile all files. |
all() -> ok
Compile all files
all_sync() -> any()
all_task(OptPid) -> any()
code_path_check(AppFilename::binary()) -> boolean()
Check if the application is present in the current code path
compile_options(File::file:filename_all()) -> {ok, list()} | false
ld() -> [code:load_ret()]
Load all changed beam files, return list of reloaded modules.
ld(Module::module()) -> code:load_ret()
Load a specific beam file, reattach any observers etc.
recompile(File::file:filename_all()) -> ok
recompile_task(File) -> any()
run_cmd(Cmd) -> any()
run_cmd(Cmd, RunOpts, Opts) -> any()
run_cmd_task(Cmd, RunOpts, Opts) -> any()
run_cmd_task_buffalo(Cmd, RunOpts, Opts) -> any()
start() -> any()
Compile all files. Called from zotonic-compile script
Generated by EDoc